
#ifndef KMM_MYMONEY_EXPORT_H
#define KMM_MYMONEY_EXPORT_H

#ifdef KMM_MYMONEY_STATIC_DEFINE
#  define KMM_MYMONEY_EXPORT
#  define KMM_MYMONEY_NO_EXPORT
#else
#  ifndef KMM_MYMONEY_EXPORT
#    ifdef kmm_mymoney_EXPORTS
        /* We are building this library */
#      define KMM_MYMONEY_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KMM_MYMONEY_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KMM_MYMONEY_NO_EXPORT
#    define KMM_MYMONEY_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KMM_MYMONEY_DEPRECATED
#  define KMM_MYMONEY_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KMM_MYMONEY_DEPRECATED_EXPORT
#  define KMM_MYMONEY_DEPRECATED_EXPORT KMM_MYMONEY_EXPORT KMM_MYMONEY_DEPRECATED
#endif

#ifndef KMM_MYMONEY_DEPRECATED_NO_EXPORT
#  define KMM_MYMONEY_DEPRECATED_NO_EXPORT KMM_MYMONEY_NO_EXPORT KMM_MYMONEY_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KMM_MYMONEY_NO_DEPRECATED
#    define KMM_MYMONEY_NO_DEPRECATED
#  endif
#endif

#endif
